@@ -1,11 +1,13 @@
 from pydantic import ConfigDict, Field, BaseModel
-from typing import Optional
+from typing import Optional, List
 from ....base_models import CompanyAssetModel
 from ....utils.types.identifier import StrObjectId
 from enum import StrEnum
 from .chatty_ai_agent import ChattyAIAgent
 from ....base_models.chatty_asset_model import ChattyAssetPreview
 from typing import ClassVar, Type, Any, Dict
+from datetime import datetime
+from zoneinfo import ZoneInfo
 
 class ChainOfThoughtInChatTrigger(StrEnum):
     """Trigger for the chain of thought in chat"""
@@ -14,6 +16,7 @@ class ChainOfThoughtInChatTrigger(StrEnum):
     MANUAL_TRIGGER = "manual_trigger"
     AUTOMATIC_TAGGING = "automatic_tagging"
     RETRY_CALL = "retry_call"
+    DOUBLE_CHECKER = "double_checker"
 
 class ChainOfThoughtInChatStatus(StrEnum):
     """Status for the chain of thought in chat"""
@@ -22,11 +25,14 @@ class ChainOfThoughtInChatStatus(StrEnum):
     FAILED = "failed"
     CANCELED = "canceled"
 
+
+
 class ChainOfThoughtInChatRequest(BaseModel):
     """Request for the chain of thought in chat"""
     id: Optional[StrObjectId] = Field(default=None, description="The id of the chain of thought")
     trigger: ChainOfThoughtInChatTrigger
-    trigger_id : str = Field(description="The id of the trigger which could be a message_id or a workflow assigned to chat link id", default="")
+    # trigger_id removed - trigger info is in: incoming_message_ids for user_message,
+    # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
     chatty_ai_agent_id : str = Field(description="The chatty ai agent at the moment of triggering the chain of thought")
     chain_of_thought : Optional[str] = Field(default=None, description="The chain of thought")
     name: str = Field(description="A title for the chain of thought", alias="title")
@@ -41,7 +47,6 @@ class ChainOfThoughtInChatRequest(BaseModel):
     def example(cls) -> dict:
         return {
             "trigger": "user_message",
-            "trigger_id": "123",
             "chatty_ai_agent_id": "456",
             "chain_of_thought": "The user's not from the jurisdiction of the law firm, so we need to offer a consultation service with extra fees",
             "name": "Out of jurisdiction - consultation service"
@@ -57,14 +62,15 @@ class ChainOfThoughtInChatPreview(ChattyAssetPreview):
     """Preview of the chain of thought in chat"""
     chat_id : StrObjectId
     trigger: ChainOfThoughtInChatTrigger
-    trigger_id : str = Field(description="The id of the trigger which could be a message_id or a workflow assigned to chat link id", default="")
+    # trigger_id removed - trigger info is in: incoming_message_ids for user_message,
+    # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
     chain_of_thought : Optional[str] = Field(default=None, description="The chain of thought")
     status: Optional[ChainOfThoughtInChatStatus] = Field(default=None, description="The status of the chain of thought")
     name: str = Field(description="A title for the chain of thought")
 
     @classmethod
     def get_projection(cls) -> dict[str, Any]:
-        return super().get_projection() | {"chat_id": 1, "trigger": 1, "trigger_id": 1, "chain_of_thought": 1, "name": 1, "status": 1}
+        return super().get_projection() | {"chat_id": 1, "trigger": 1, "chain_of_thought": 1, "name": 1, "status": 1}
 
     @classmethod
     def from_dict(cls, data: dict) -> 'ChainOfThoughtInChatPreview':
@@ -77,7 +83,6 @@ class ChainOfThoughtInChatPreview(ChattyAssetPreview):
             name=asset.name,
             chat_id=asset.chat_id,
             trigger=asset.trigger,
-            trigger_id=asset.trigger_id,
             chain_of_thought=asset.chain_of_thought,
             status=asset.status,
             company_id=asset.company_id,
@@ -91,10 +96,11 @@ class ChainOfThoughtInChat(CompanyAssetModel):
     """Chain of thought in chat"""
     chat_id : StrObjectId
     trigger: ChainOfThoughtInChatTrigger = Field(description="The trigger of the chain of thought")
-    trigger_id : str = Field(description="The id of the trigger which could be a message_id or a workflow assigned to chat link id", default="")
+    # trigger_id removed - trigger info is in: incoming_message_ids for user_message,
+    # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
     status: ChainOfThoughtInChatStatus = Field(default=ChainOfThoughtInChatStatus.PROCESSING, description="The status of the chain of thought")
     chatty_ai_agent_id : StrObjectId = Field(description="The chatty ai agent id")
-    chatty_ai_agent : Dict[str, Any] = Field(description="The chatty ai agent at the moment of triggering the chain of thought", default_factory=dict)
+    chatty_ai_agent : Dict[str, Any] = Field(description="The chatty ai agent at the moment of triggering the chain of thought", exclude=True,default_factory=dict)
     chain_of_thought : Optional[str] = Field(default=None, description="The chain of thought")
     name: str = Field(description="A title for the chain of thought", alias="title")
     preview_class: ClassVar[Type[ChattyAssetPreview]] = ChainOfThoughtInChatPreview
@@ -104,3 +110,4 @@ class ChainOfThoughtInChat(CompanyAssetModel):
             self.chain_of_thought = cot
         else:
             self.chain_of_thought += f"\n{cot}"
+
