@@ -46,6 +46,7 @@ class N8NWorkspaceAgentType(StrEnum):
 class N8NWorkspaceAgentTypeParameters(BaseModel):
     """Parameters for the N8N workspace agent type"""
     calendars: Optional[List[str]] = Field(default=None, description="List of emails to be used as calendars")
+    scheduling_rules : Optional[str] = Field(default=None, description="Scheduling rules to be used for the calendar scheduler, when to schedule in each calendar, hours of the day, days of the week, etc.")
     tokko_broker_api_key: Optional[str] = Field(default=None, description="The API key for the Tokko broker")
 
 class ChattyAIAgentPreview(ChattyAssetPreview):
@@ -69,12 +70,6 @@ class ChattyAIAgentPreview(ChattyAssetPreview):
             n8n_workspace_agent_type=asset.n8n_workspace_agent_type
         )
 
-class ProductsInfoLevel(StrEnum):
-    """Products info level"""
-    NAME = "name"
-    DESCRIPTION = "description"
-    ALL = "all"
-
 class ChattyAIAgent(CompanyAssetModel):
     """AI Agent configuration model"""
     # Basic Information
@@ -86,7 +81,6 @@ class ChattyAIAgent(CompanyAssetModel):
     control_triggers: List[str] = Field(default_factory=list, description="Triggers for human handoff")
     test_source_id: Optional[StrObjectId] = Field(default=None, description="Test source id")
     n8n_workspace_agent_type: N8NWorkspaceAgentType = Field(default=N8NWorkspaceAgentType.DEFAULT, description="The type of agent to redirect the message to")
-    products_info_level : ProductsInfoLevel = Field(default=ProductsInfoLevel.NAME, description="Whether to include all products info in the prompt or just the name / description")
     n8n_workspace_agent_type_parameteres : N8NWorkspaceAgentTypeParameters = Field(default=N8NWorkspaceAgentTypeParameters(), description="The parameters for the N8N workspace agent type")
 
     preview_class: ClassVar[type[ChattyAIAgentPreview]] = ChattyAIAgentPreview
@@ -95,6 +89,8 @@ class ChattyAIAgent(CompanyAssetModel):
     contexts: List[StrObjectId] = Field(default_factory=list, description="List of context items")
     faqs: List[StrObjectId] = Field(default_factory=list, description="Frequently asked questions")
     examples: List[StrObjectId] = Field(default_factory=list, description="Training examples")
+    double_checker_enabled: bool = Field(default=False, description="Whether the double checker is enabled")
+    double_checker_instructions: Optional[str] = Field(default=None, description="Instructions for the double checker")
 
     """json example:
     {
