@@ -1,4 +1,11 @@
 from enum import StrEnum
+import os
+
+class Environment(StrEnum):
+    PRODUCTION = "PROD"
+    DEVELOPMENT = "DEV"
+    LOCAL = "LOCAL"
+
 
 class Area(StrEnum):
     WAITING_AGENT = "WAITING AGENT"
