@@ -269,4 +269,15 @@ class ContinuousConversationHelper:
         central_notif_content = ChattyContentCentral(body=body, status=CentralNotificationStatus.WARNING, calls_to_action=[cta.value for cta in cc.calls_to_action])
         central_notif = CentralNotificationFactory.continuous_conversation_status(cc=cc, content=central_notif_content)
         ChatService.add_central_notification(central_notification=central_notif, chat=chat)
+        return cc
+
+    @staticmethod
+    def handle_failed_template_cc(chat: Chat, cc: ContinuousConversation, error_details: str) -> ContinuousConversation:
+        """This is for the handling of a failed template CC"""
+        cc.set_status(status=ContinuousConversationStatus.FAILED)
+        body=f"Continuous conversation failed to be sent: {error_details}"
+        logger.debug(f"{body} | CC status: {cc.status} | CC id: {cc.id} | chat id: {chat.identifier}")
+        central_notif_content = ChattyContentCentral(body=body, status=CentralNotificationStatus.ERROR, calls_to_action=[cta.value for cta in cc.calls_to_action])
+        central_notif = CentralNotificationFactory.continuous_conversation_status(cc=cc, content=central_notif_content)
+        ChatService.add_central_notification(central_notification=central_notif, chat=chat)
         return cc
\ No newline at end of file
