@@ -1,6 +1,6 @@
 
 from letschatty.models import StrObjectId
-from letschatty.models.ai_microservices.lambda_events import DoubleCheckerForIncomingMessagesAnswerCallbackEvent, DoubleCheckerForIncomingMessagesAnswerEvent, FixBuggedAiAgentsCallsInChatsEvent, QualityTestEventData, QualityTestsForUpdatedAIComponentEvent, QualityTestsForUpdatedAIComponentEventData
+from letschatty.models.ai_microservices.lambda_events import DoubleCheckerForIncomingMessagesAnswerCallbackEvent, DoubleCheckerForIncomingMessagesAnswerEvent, FixBuggedAiAgentsCallsInChatsEvent, GetChatWithPromptForFollowUpEvent, GetChatWithPromptForIncomingMessageEvent, QualityTestEventData, QualityTestsForUpdatedAIComponentEvent, QualityTestsForUpdatedAIComponentEventData, ManualTriggerEvent, CancelExecutionEvent, AssignAIAgentToChatEvent, RemoveAIAgentFromChatEvent, UpdateAIAgentModeInChatEvent, EscalateAIAgentInChatEvent, UnescalateAIAgentInChatEvent
 from letschatty.models.ai_microservices.lambda_invokation_types import InvokationType
 from letschatty.models.ai_microservices import AllQualityTestEvent, AllQualityTestEventData, FollowUpEvent, IncomingMessageEvent, QualityTestEvent, QualityTestInteractionCallbackEvent, SmartTaggingCallbackEvent, IncomingMessageCallbackEvent, QualityTestCallbackEvent, LambdaAiEvent, SmartTaggingEvent, SmartTaggingPromptEvent
 from letschatty.models.base_models.ai_agent_component import AiAgentComponent
@@ -41,6 +41,24 @@ class LambdaEventFactory:
                 return DoubleCheckerForIncomingMessagesAnswerEvent(**event_data)
             case InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER_CALLBACK:
                 return DoubleCheckerForIncomingMessagesAnswerCallbackEvent(**event_data)
+            case InvokationType.GET_CHAT_WITH_PROMPT_INCOMING_MESSAGE:
+                return GetChatWithPromptForIncomingMessageEvent(**event_data)
+            case InvokationType.GET_CHAT_WITH_PROMPT_FOLLOW_UP:
+                return GetChatWithPromptForFollowUpEvent(**event_data)
+            case InvokationType.MANUAL_TRIGGER:
+                return ManualTriggerEvent(**event_data)
+            case InvokationType.CANCEL_EXECUTION:
+                return CancelExecutionEvent(**event_data)
+            case InvokationType.ASSIGN_AI_AGENT_TO_CHAT:
+                return AssignAIAgentToChatEvent(**event_data)
+            case InvokationType.REMOVE_AI_AGENT_FROM_CHAT:
+                return RemoveAIAgentFromChatEvent(**event_data)
+            case InvokationType.UPDATE_AI_AGENT_MODE_IN_CHAT:
+                return UpdateAIAgentModeInChatEvent(**event_data)
+            case InvokationType.ESCALATE_AI_AGENT_IN_CHAT:
+                return EscalateAIAgentInChatEvent(**event_data)
+            case InvokationType.UNESCALATE_AI_AGENT_IN_CHAT:
+                return UnescalateAIAgentInChatEvent(**event_data)
             case _:
                 raise ValueError(f"Invalid event type: {event_type}")
 
